Core API
========

This section documents the core tracing functionality in pydftracer.

dftracer Class
--------------

.. autoclass:: dftracer.python.dftracer
   :members:
   :undoc-members:
   :show-inheritance:

dft_fn Class
------------

.. autoclass:: dftracer.python.dft_fn
   :members:
   :undoc-members:
   :show-inheritance:

Common Utilities
----------------

Tag Types
~~~~~~~~~

.. autoclass:: dftracer.python.TagType
   :members:
   :undoc-members:

.. autoclass:: dftracer.python.TagDType
   :members:
   :undoc-members:

.. autoclass:: dftracer.python.TagValue
   :members:
   :undoc-members:
   :show-inheritance:

Profiler Protocol
~~~~~~~~~~~~~~~~~

.. autoclass:: dftracer.python.common.ProfilerProtocol
   :members:
   :undoc-members:

Functions
---------

.. autofunction:: dftracer.python.initialize
.. autofunction:: dftracer.python.finalize
.. autofunction:: dftracer.python.get_time
